@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 7.5 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -17,14 +17,12 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcsunits.h,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
+  $Id: wcsunits.h,v 7.5 2021/03/20 05:54:58 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.5 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -161,42 +159,44 @@
 *                            or not (see notes).
 *
 * Notes:
-*   Translation of non-standard unit specifications: apart from leading and
-*   trailing blanks, a case-sensitive match is required for the aliases listed
-*   below, in particular the only recognized aliases with metric prefixes are
-*   "KM", "KHZ", "MHZ", and "GHZ".  Potentially unsafe translations of "D",
-*   "H", and "S", shown in parentheses, are optional.
+*   1: Translation of non-standard unit specifications: apart from leading and
+*      trailing blanks, a case-sensitive match is required for the aliases
+*      listed below, in particular the only recognized aliases with metric
+*      prefixes are "KM", "KHZ", "MHZ", and "GHZ".  Potentially unsafe
+*      translations of "D", "H", and "S", shown in parentheses, are optional.
 *
-=     Unit       Recognized aliases
-=     ----       -------------------------------------------------------------
-=     Angstrom   angstrom
-=     arcmin     arcmins, ARCMIN, ARCMINS
-=     arcsec     arcsecs, ARCSEC, ARCSECS
-=     beam       BEAM
-=     byte       Byte
-=     d          day, days, (D), DAY, DAYS
-=     deg        degree, degrees, Deg, Degree, Degrees, DEG, DEGREE, DEGREES
-=     GHz        GHZ
-=     h          hr, (H), HR
-=     Hz         hz, HZ
-=     kHz        KHZ
-=     Jy         JY
-=     K          kelvin, kelvins, Kelvin, Kelvins, KELVIN, KELVINS
-=     km         KM
-=     m          metre, meter, metres, meters, M, METRE, METER, METRES, METERS
-=     min        MIN
-=     MHz        MHZ
-=     Ohm        ohm
-=     Pa         pascal, pascals, Pascal, Pascals, PASCAL, PASCALS
-=     pixel      pixels, PIXEL, PIXELS
-=     rad        radian, radians, RAD, RADIAN, RADIANS
-=     s          sec, second, seconds, (S), SEC, SECOND, SECONDS
-=     V          volt, volts, Volt, Volts, VOLT, VOLTS
-=     yr         year, years, YR, YEAR, YEARS
+=        Unit       Recognized aliases
+=        ----       ----------------------------------------------------------
+=        Angstrom   Angstroms angstrom angstroms
+=        arcmin     arcmins, ARCMIN, ARCMINS
+=        arcsec     arcsecs, ARCSEC, ARCSECS
+=        beam       BEAM
+=        byte       Byte
+=        d          day, days, (D), DAY, DAYS
+=        deg        degree, degrees, Deg, Degree, Degrees, DEG, DEGREE,
+=                   DEGREES
+=        GHz        GHZ
+=        h          hr, (H), HR
+=        Hz         hz, HZ
+=        kHz        KHZ
+=        Jy         JY
+=        K          kelvin, kelvins, Kelvin, Kelvins, KELVIN, KELVINS
+=        km         KM
+=        m          metre, meter, metres, meters, M, METRE, METER, METRES,
+=                   METERS
+=        min        MIN
+=        MHz        MHZ
+=        Ohm        ohm
+=        Pa         pascal, pascals, Pascal, Pascals, PASCAL, PASCALS
+=        pixel      pixels, PIXEL, PIXELS
+=        rad        radian, radians, RAD, RADIAN, RADIANS
+=        s          sec, second, seconds, (S), SEC, SECOND, SECONDS
+=        V          volt, volts, Volt, Volts, VOLT, VOLTS
+=        yr         year, years, YR, YEAR, YEARS
 *
-*   The aliases "angstrom", "ohm", and "Byte" for (Angstrom, Ohm, and byte)
-*   are recognized by wcsulexe() itself as an unofficial extension of the
-*   standard, but they are converted to the standard form here.
+*      The aliases "angstrom", "ohm", and "Byte" for (Angstrom, Ohm, and byte)
+*      are recognized by wcsulexe() itself as an unofficial extension of the
+*      standard, but they are converted to the standard form here.
 *
 *
 * wcsulexe() - FITS units specification parser
